function data = load_fld (filename)

% Quick script to load data from a .fld format file
% 
% data = load_fld(filename)
%
% Currently, this makes huge assumptions about format of data...

%------------------------------------------------------------------------------
% Dom Layfield, August 2002
%------------------------------------------------------------------------------
% Note that this does not parse the file properly.  Rather, it assumes that
% the tokens are in exactly the format with no variation.   Would be nice to
% do this right, but there don't appear to be any parsing tools in MATLAB.
%------------------------------------------------------------------------------

% Open file for reading
fid = fopen(filename, 'r', 'ieee-be');

% Read from file, a line at a time
while ~feof(fid)
  linestart = ftell(fid);
  line = fgetl(fid);
  ll = length(line);
  % Look for separator between header and data
  if ll>1 & double(line(1,2))==[12,12]
     % Move position in file to immediately following separator
     fseek(fid, linestart+2, -1);
     break;
  end
  % Break line up into whitespace-separated tokens, ignoring comments
  while ~isempty(line) & line(1)~='#'
     [token, c, errmsg, next] = sscanf(line, '%s', 1);
     line = line(next:end);
     [str1,str2] = split_string(token,'=');
     switch lower(str1)
        case 'ndim'
           ndim = sscanf(str2,'%i');
        case {'dim1', 'dim2', 'dim3', 'dim4'}
           dims(str2num(str1(4))) = sscanf(str2,'%i');
        case 'nspace'
        case 'veclen'
        case 'data'
           dtype = lower(str2);
        case 'field'
        otherwise
           warning ('Unrecognized token in .fld file');
     end
  end
end

% Read data following separator
data = fread(fid,inf,'single');

% Check that data was size we expected
sz = size(data);
if prod(sz) ~= prod(dims)
   warning('Data does not match header dimensions.'); 
else
   % If size is good, reshape accordingly.
   data = reshape(data, dims);
end
           
% Close file 
fclose(fid);        
return


%------------------------------------------------------------------------------
% SUBFUNCTIONS BELOW 
%------------------------------------------------------------------------------

% Splits a string into two halfs, divided by a separator string
function [s1,s2] = split_string(l,ss)
oc = strfind(l,ss);
if ~isempty(oc)
   s1 = l(1:oc(1)-1);
   s2 = l(oc(1)+length(ss):end);
else
   s1 = l;
   s2 = '';
end
return
